﻿using System;
using Infragistics;
using Foundation;
using CoreGraphics;

namespace CustomSparklineColumn_Xamarin
{
	public class IGSparklineColumnCell : IGGridViewCell
	{
		//IGSparklineViewDataSourceHelper _helper;
		//IGSparklineView _sparkline;


		IGChartView _chartView;
		IGLabel _label;
		//IGGridViewSingleFieldMultiColumnDataSourceHelper _helper;
		IGCategorySeriesDataSourceHelper _helper;
		IGNumericYAxis _yAxis;
		IGCategoryXAxis _xAxis;

		public IGSparklineColumnCell (string reuseID) : base(reuseID)
		{
			_chartView = new IGChartView ();
			_chartView.UserInteractionEnabled = false;
			this.AddSubview(_chartView);

			// for this sample we "know" that we are going to use either a line or column series, so the Axis objects will be set up here.
			// otherwise they would have to be set up and cleared in teh setupCell method

			_xAxis = new IGCategoryXAxis ("x");
			_chartView.AddAxis (_xAxis);

			_yAxis = new IGNumericYAxis ("y");
			_chartView.AddAxis (_yAxis);

			_label = new IGLabel ();
			//_label.BackgroundColor = UIKit.UIColor.Clear;

			this.AddSubview (_label);
			_label.TextColor = UIKit.UIColor.Red;


		}
		// keeps the sparkline correctly sized.
		public override void SetupSize (CGSize size)
		{
			float padding = 5.0f;

			this._label.Frame= this._chartView.Frame = new CGRect (0, 
				padding, 
				size.Width, 
				size.Height - (padding * 2));
		}
		// makes a datasource helper and assigns to chart.
		internal void SetUpCell(TeamSeasonData data, int viewToShow)
		{
			// first clean up anything that might be in chart due to recycling;
			_helper = null;
			if (_chartView.Series!=null && _chartView.Series.Length > 0) {
				IGSeries oldSeries =(IGSeries) _chartView.Series [0];
				_chartView.RemoveSeries (oldSeries);
			
			}
			NSObject[] dataArray = data.RecordData;

			_helper = new IGCategorySeriesDataSourceHelper (dataArray);

			_label.Text = data.IndexNumber.ToString();

			if (viewToShow == 0) {
				IGColumnSeries columnSeries = new IGColumnSeries ("mySeries");

				_chartView.AddSeries (columnSeries);
				columnSeries.XAxis = _xAxis;
				columnSeries.YAxis = _yAxis;
				columnSeries.Brush = new IGBrush (UIKit.UIColor.Blue);
				columnSeries.DataSource = _helper;
			} else {
				IGLineSeries columnSeries = new IGLineSeries ("mySeries");

				_chartView.AddSeries (columnSeries);
				columnSeries.XAxis = _xAxis;
				columnSeries.YAxis = _yAxis;
				columnSeries.Brush = new IGBrush (UIKit.UIColor.Blue);
				columnSeries.DataSource = _helper;
			}


		}
		// since this is the only object holding onto the _helper, we can just nil it out here to ensure destruction.
		public override void CellDetached ()
		{
			base.CellDetached ();
			_helper = null;
		}
	}
}

